@@ -29,6 +29,7 @@
 #include "procproperties.h"
 #include "proctable.h"
 #include "util.h"
+#include "e_date.h"
 
 enum
 {
@@ -76,7 +77,7 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
 #endif
         { N_("CPU"), g_strdup_printf("%d%%", info->pcpu)},
         { N_("CPU Time"), procman::format_duration_for_display(100 * info->cpu_time / GsmApplication::get()->frequency) },
-        { N_("Started"), g_strdup_printf("%s", ctime((const time_t*)(&info->start_time)))},
+        { N_("Started"), procman_format_date_for_display(info->start_time) },
         { N_("Nice"), g_strdup_printf("%d", info->nice)},
         { N_("Priority"), g_strdup_printf("%s", procman::get_nice_level(info->nice)) },
         { N_("ID"), g_strdup_printf("%d", info->pid)},
